@@ -290,6 +290,75 @@ class CreateAppScanTaskResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class CreateFlySecMiniAppProfessionalScanTaskRequest(AbstractModel):
+    """CreateFlySecMiniAppProfessionalScanTask请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param MiniAppID: 小程序AppID
+        :type MiniAppID: str
+        :param MiniAppName: 小程序名称
+        :type MiniAppName: str
+        :param Mode: 诊断模式 2:深度诊断
+        :type Mode: int
+        :param CorpName: 公司名称
+        :type CorpName: str
+        :param Mobile: 手机号码
+        :type Mobile: str
+        :param Email: 电子邮箱
+        :type Email: str
+        :param Remark: 备注信息
+        :type Remark: str
+        """
+        self.MiniAppID = None
+        self.MiniAppName = None
+        self.Mode = None
+        self.CorpName = None
+        self.Mobile = None
+        self.Email = None
+        self.Remark = None
+
+
+    def _deserialize(self, params):
+        self.MiniAppID = params.get("MiniAppID")
+        self.MiniAppName = params.get("MiniAppName")
+        self.Mode = params.get("Mode")
+        self.CorpName = params.get("CorpName")
+        self.Mobile = params.get("Mobile")
+        self.Email = params.get("Email")
+        self.Remark = params.get("Remark")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class CreateFlySecMiniAppProfessionalScanTaskResponse(AbstractModel):
+    """CreateFlySecMiniAppProfessionalScanTask返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Ret: 返回值, 0:成功, 其他值请查看“返回值”定义
+        :type Ret: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Ret = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.Ret = params.get("Ret")
+        self.RequestId = params.get("RequestId")
+
+
 class CreateFlySecMiniAppScanTaskRepeatRequest(AbstractModel):
     """CreateFlySecMiniAppScanTaskRepeat请求参数结构体
 
@@ -299,7 +368,7 @@ class CreateFlySecMiniAppScanTaskRepeatRequest(AbstractModel):
         r"""
         :param MiniAppID: 小程序AppID
         :type MiniAppID: str
-        :param Mode: 诊断模式 1:基础诊断，2:深度诊断
+        :param Mode: 诊断模式 1:基础诊断
         :type Mode: int
         :param OrgTaskID: 原任务id
         :type OrgTaskID: str
@@ -368,7 +437,7 @@ class CreateFlySecMiniAppScanTaskRequest(AbstractModel):
         r"""
         :param MiniAppID: 小程序AppID
         :type MiniAppID: str
-        :param Mode: 诊断模式 1:基础诊断，2:深度诊断
+        :param Mode: 诊断模式 1:基础诊断
         :type Mode: int
         :param MiniAppTestAccount: 小程序测试账号(自有账号体系需提供,其他情况不需要)
         :type MiniAppTestAccount: str
@@ -514,7 +583,7 @@ class DescribeFlySecMiniAppReportUrlRequest(AbstractModel):
         :type MiniAppID: str
         :param Mode: 诊断方式 1:基础诊断，2:深度诊断
         :type Mode: int
-        :param ReportType: 诊断报告类型 0:基础诊断报告, 1:总裁版诊断报告
+        :param ReportType: 诊断报告类型 0:基础诊断报告，1:总裁版诊断报告，2:诊断报告json结果
         :type ReportType: int
         """
         self.TaskID = None
@@ -988,7 +1057,7 @@ class DescribeScanTaskReportUrlRequest(AbstractModel):
         :type TaskID: str
         :param Platform: 应用平台, 0:android, 1:ios, 2:小程序
         :type Platform: int
-        :param ReportType: 报告类型, 0:诊断报告, 1:堆栈报告
+        :param ReportType: 报告类型, 0:诊断报告, 1:堆栈报告(预留), 2:视频证据(预留), 3:报告json结果
         :type ReportType: int
         :param TaskType: 任务类型, 0:基础版, 1:专家版, 2:本地化
         :type TaskType: int
@@ -1029,12 +1098,16 @@ class DescribeScanTaskReportUrlResponse(AbstractModel):
         :param ReportTitle: 诊断报告/堆栈名称
 注意：此字段可能返回 null，表示取不到有效值。
         :type ReportTitle: str
+        :param ReportResult: 诊断json结果内容
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ReportResult: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.Result = None
         self.ReportUrl = None
         self.ReportTitle = None
+        self.ReportResult = None
         self.RequestId = None
 
 
@@ -1042,6 +1115,7 @@ class DescribeScanTaskReportUrlResponse(AbstractModel):
         self.Result = params.get("Result")
         self.ReportUrl = params.get("ReportUrl")
         self.ReportTitle = params.get("ReportTitle")
+        self.ReportResult = params.get("ReportResult")
         self.RequestId = params.get("RequestId")
 
 
