@@ -17,6 +17,9 @@
 # CAM签名/鉴权错误。
 AUTHFAILURE = 'AuthFailure'
 
+# 操作失败。
+FAILEDOPERATION = 'FailedOperation'
+
 # 重复添加。
 FAILEDOPERATION_REPETITIONADD = 'FailedOperation.RepetitionAdd'
 
